%bcond_with bootstrap

Name:           objectweb-asm
Version:        9.6
Release:        %mkrel 2
Group:          Development/Java
Summary:        Java bytecode manipulation and analysis framework
License:        BSD-3-Clause
URL:            https://asm.ow2.org/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
Source1:        aggregator.pom
Source2:        https://repo1.maven.org/maven2/org/ow2/asm/asm/%{version}/asm-%{version}.pom
Source3:        https://repo1.maven.org/maven2/org/ow2/asm/asm-analysis/%{version}/asm-analysis-%{version}.pom
Source4:        https://repo1.maven.org/maven2/org/ow2/asm/asm-commons/%{version}/asm-commons-%{version}.pom
Source5:        https://repo1.maven.org/maven2/org/ow2/asm/asm-test/%{version}/asm-test-%{version}.pom
Source6:        https://repo1.maven.org/maven2/org/ow2/asm/asm-tree/%{version}/asm-tree-%{version}.pom
Source7:        https://repo1.maven.org/maven2/org/ow2/asm/asm-util/%{version}/asm-util-%{version}.pom
# The source contains binary jars that cannot be verified for licensing and could be proprietary
Source9:        generate-tarball.sh
Source10:       tools-retrofitter.pom

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.ow2.asm:asm)
%endif

# Explicit javapackages-tools requires since asm-processor script uses
# /usr/share/java-utils/java-functions
Requires:       javapackages-tools

%description
ASM is an all purpose Java bytecode manipulation and analysis
framework.  It can be used to modify existing classes or dynamically
generate classes, directly in binary form.  Provided common
transformations and analysis algorithms allow to easily assemble
custom complex transformations and code analysis tools.

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
This package provides %{summary}.

%prep
%setup -q

# A custom pom to aggregate the build
cp -p %{SOURCE1} pom.xml

cp -p %{SOURCE10} tools/retrofitter/pom.xml

# Insert poms into modules
for pom in asm asm-analysis asm-commons asm-test asm-tree asm-util; do
  cp -p ${RPM_SOURCE_DIR}/${pom}-%{version}.pom ${pom}/pom.xml
  %pom_add_dep org.fedoraproject.xmvn.objectweb-asm:tools-retrofitter::provided ${pom}
  %pom_add_plugin org.apache.maven.plugins:maven-antrun-plugin ${pom}
  %pom_set_parent org.fedoraproject.xmvn.objectweb-asm:aggregator:any ${pom}
  %pom_xpath_inject pom:parent '<relativePath>..</relativePath>' ${pom}
done

%pom_add_dep org.ow2.asm:asm-tree:%{version} asm-analysis

# Don't ship poms used for build only
%mvn_package :aggregator __noinstall
%mvn_package :tools-retrofitter __noinstall

# Don't ship the test framework to avoid runtime dep on junit
%mvn_package :asm-test __noinstall

%build
%mvn_build -f -- -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%jpackage_script org.objectweb.asm.xml.Processor "" "" %{name}/asm:%{name}/asm-attrs:%{name}/asm-util %{name}-processor true

%files -f .mfiles
%license LICENSE.txt
%{_bindir}/%{name}-processor

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 9.6-2.mga10
+ Revision: 2223826
- Mageia 10 Mass Rebuild

* Sun May 26 2024 daviddavid <daviddavid> 9.6-1.mga10
+ Revision: 2067723
- Update to upstream version 9.6
- Rebuilt for java-21-openjdk as system jdk

* Thu Sep 14 2023 daviddavid <daviddavid> 9.5-1.mga10
+ Revision: 1986457
- Update to upstream  version 9.5

* Mon Jul 25 2022 neoclust <neoclust> 9.3-2.mga9
+ Revision: 1871095
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 9.3-1.mga9
+ Revision: 1870812
- New version 9.3
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Wed Mar 03 2021 daviddavid <daviddavid> 9.1-1.mga9
+ Revision: 1696819
- Update to latest upstream release 9.1

* Thu Sep 03 2020 daviddavid <daviddavid> 8.0.1-1.mga8
+ Revision: 1621316
- Version 8.0.1
- Add 0002-Catch-CompileException-in-test.patch to fix compilation of a test
- Make generate-tarball.sh actually compress the tarball
- Rebuilt for JDK-11
- Revert an upstream change to prevent breaking API change
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Wed Jul 17 2019 daviddavid <daviddavid> 7.0-1.mga8
+ Revision: 1422204
- Update to latest upstream 7.0 release
- Removes package asm-xml (deprecated since 6.1)

* Wed Dec 12 2018 daviddavid <daviddavid> 6.2.1-4.mga7
+ Revision: 1340809
- remove previous provide osgi(org.objectweb.asm.tree)

* Thu Dec 06 2018 guillomovitch <guillomovitch> 6.2.1-3.mga7
+ Revision: 1338693
- rebuild with junit and osgi support

* Mon Nov 26 2018 wally <wally> 6.2.1-2.mga7
+ Revision: 1335303
- temporary provide osgi(org.objectweb.asm.tree) to make eclipse installable

* Sat Nov 17 2018 guillomovitch <guillomovitch> 6.2.1-1.mga7
+ Revision: 1330354
- new version 6.2.1

* Wed Sep 19 2018 umeabot <umeabot> 5.1-5.mga7
+ Revision: 1265375
- Mageia 7 Mass Rebuild

* Sun May 14 2017 neoclust <neoclust> 5.1-4.mga6
+ Revision: 1101075
- New version 5.1
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 5.0.4-2.mga6
+ Revision: 977750
- First rebuild of the java stack
- sync package objectweb-asm with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Dec 27 2014 daviddavid <daviddavid> 5.0.2-3.mga5
+ Revision: 806545
- obsoletes forgotten objectweb-asm4-javadoc package
- attribute the objectweb-asm-javadoc package to Documentation group

* Thu Dec 25 2014 pterjan <pterjan> 5.0.2-2.mga5
+ Revision: 805678
- Clean rebuild
- Sync with Fedora 21 (Update to 5.0.2)

* Wed Oct 15 2014 umeabot <umeabot> 5.0.1-3.mga5
+ Revision: 745632
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.0.1-2.mga5
+ Revision: 682967
- Mageia 5 Mass Rebuild

* Mon Apr 07 2014 dmorgan <dmorgan> 5.0.1-1.mga5
+ Revision: 612577
- New version

* Tue Oct 22 2013 umeabot <umeabot> 0:3.3.1-10.mga4
+ Revision: 545804
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 dmorgan <dmorgan> 0:3.3.1-9.mga4
+ Revision: 501847
- Obsoletes old versions

* Fri Sep 20 2013 dmorgan <dmorgan> 0:3.3.1-8.mga4
+ Revision: 482627
- Rebuild against new javapackages

* Sat Jul 13 2013 dmorgan <dmorgan> 0:3.3.1-7.mga4
+ Revision: 453780
- Make jetty orbit depmap point to asm-all jar

* Sat Jul 13 2013 dmorgan <dmorgan> 0:3.3.1-6.mga4
+ Revision: 453776
- Add depmap for org.eclipse.jetty.orbit

* Sun Feb 17 2013 dmorgan <dmorgan> 0:3.3.1-5.mga3
+ Revision: 398876
- Clean spec file

* Sat Jan 12 2013 umeabot <umeabot> 0:3.3.1-4.mga3
+ Revision: 361100
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 25 2011 dmorgan <dmorgan> 0:3.3.1-3.mga2
+ Revision: 187560
- Use poms produced by the build not foreign ones. (Fedora)

* Wed Jul 20 2011 dmorgan <dmorgan> 0:3.3.1-2.mga2
+ Revision: 127026
- Fix groups

* Tue Jul 19 2011 dmorgan <dmorgan> 0:3.3.1-1.mga2
+ Revision: 126075
- Update to version 3.3.1

* Mon Jan 17 2011 dmorgan <dmorgan> 0:3.2-1.mga1
+ Revision: 21686
- remove fc macros
- imported package objectweb-asm


* Tue Jul 13 2010 Orion Poplawski <orion@cora.nwra.com>  0:3.2.1-2
- Change depmap parent id to asm (bug #606659)

* Thu Apr 15 2010 Fernando Nasser <fnasser@redhat.com> 0:3.2.1
- Upgrade to 3.2

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:3.1-7.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:3.1-6.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Oct 23 2008 David Walluck <dwalluck@redhat.com> 0:3.1-5.1
- build for Fedora

* Tue Oct 23 2008 David Walluck <dwalluck@redhat.com> 0:3.1-5
- add OSGi manifest (Alexander Kurtakov)

* Mon Oct 20 2008 David Walluck <dwalluck@redhat.com> 0:3.1-4
- remove Class-Path from MANIFEST.MF
- add unversioned javadoc symlink
- remove javadoc scriptlets
- fix directory ownership
- remove build requirement on dos2unix

* Fri Feb 08 2008 Ralph Apel <r.apel@r-apel.de> - 0:3.1-3jpp
- Add poms and depmap frags with groupId of org.objectweb.asm !
- Add asm-all.jar 
- Add -javadoc Requires post and postun
- Restore Vendor, Distribution

* Thu Nov 22 2007 Fernando Nasser <fnasser@redhat.com> - 0:3.1-2jpp
- Fix EOL of txt files
- Add dependency on jaxp 

* Thu Nov 22 2007 Fernando Nasser <fnasser@redhat.com> - 0:3.1-1jpp
- Upgrade to 3.1

* Wed Aug 22 2007 Fernando Nasser <fnasser@redhat.com> - 0:3.0-1jpp
- Upgrade to 3.0
- Rename to include objectweb- prefix as requested by ObjectWeb

* Thu Jan 05 2006 Fernando Nasser <fnasser@redhat.com> - 0:2.1-2jpp
- First JPP 1.7 build

* Thu Oct 06 2005 Ralph Apel <r.apel at r-apel.de> 0:2.1-1jpp
- Upgrade to 2.1

* Fri Mar 11 2005 Sebastiano Vigna <vigna at acm.org> 0:2.0.RC1-1jpp
- First release of the 2.0 line.
